@@ -211,7 +211,7 @@ class PreseemGrpcClient(object):
                     return x
             except grpc.RpcError as err:
                 logging.debug('Error calling service: %s (%s)', err.code(), err.details())
-                if err.code() in (grpc.StatusCode.NOT_FOUND, grpc.StatusCode.UNKNOWN, grpc.StatusCode.UNIMPLEMENTED):
+                if err.code() in (grpc.StatusCode.INTERNAL, grpc.StatusCode.NOT_FOUND, grpc.StatusCode.UNKNOWN, grpc.StatusCode.UNIMPLEMENTED):
                     raise
                 if retry_num == num_retries:
                     logging.warning('Error calling service: %s (%s)', err.code(), err.details())
